(function() {
  var chalk, util;

  chalk = require('chalk');

  util = require('alinex-util');

  exports.optional = {
    describe: function() {
      var value;
      if (!(this.schema.optional || (this.schema["default"] != null))) {
        return '';
      }
      if (this.schema["default"]) {
        value = this.schema["default"] instanceof Function ? '[function]' : util.inspect(this.schema["default"]);
        return "It's optional and will be set to `" + value + "` if not specified. ";
      } else {
        return "It's optional. ";
      }
    },
    check: function() {
      if (this.value != null) {
        return false;
      }
      if (this.schema["default"] != null) {
        this.value = this.schema["default"];
        if (this.debug.enabled) {
          this.debug(chalk.grey(this.name + ": use default " + (this.inspectValue())));
        }
        return false;
      }
      if (this.schema.optional) {
        delete this.value;
        if (this.debug.enabled) {
          this.debug(chalk.grey(this.name + ": result " + (this.inspectValue())));
        }
        return true;
      }
      return this.sendError("A value is needed", function(err) {
        return err;
      });
    }
  };

  exports.baseSchema = {
    title: {
      title: "Title",
      description: "the title used to describe the element",
      type: 'string',
      optional: true
    },
    description: {
      title: "Description",
      description: "the free description of the element",
      type: 'string',
      optional: true
    },
    key: {
      title: "Binding to Keyname",
      description: "the mapping to which key names in an object this element belongs",
      type: 'regexp',
      optional: true
    },
    type: {
      title: "Type",
      description: "the type of element",
      type: 'string'
    },
    optional: {
      title: "Optional",
      description: "a flag defining if this element is optional",
      type: 'boolean',
      optional: true
    }
  };

}).call(this);

//# sourceMappingURL=rules.map