
/*
And
=================================================
Collection of types combined with logical and.

This checks will be done in series to allow each one to possibly change the value
and give it on.

This is used to give multiple rules which will be executed in a series and
all have to succeed.

__Option:__

- `and` - (array) with multiple check rules

With this it is possible to use a string-check to sanitize and then use an
other test to finalize the value like:

``` coffee
validator.check
  name: 'test'        # name to be displayed in errors (optional)
  value: input        # value to check
  schema:             # definition of checks
    type: 'and'
    and: [
      type: 'string'
      toString: true
      replace: [/,/g, '.']
    ,
      type: 'float'
    ]
, (err, result) ->
   * do something
```

This allows to give float numbers in the european format: xx,x


Schema Specification
---------------------------------------------------
{@schema #selfcheck}
 */

(function() {
  var async, rules, util;

  async = require('async');

  util = require('alinex-util');

  rules = require('../helper/rules');

  exports.describe = function(cb) {
    var i, ref, results1, text;
    text = "All of the following checks have to succeed:";
    text += rules.optional.describe.call(this);
    text = text.replace(/\. It's/, ' which is');
    return async.map((function() {
      results1 = [];
      for (var i = 0, ref = this.schema.and.length - 1; 0 <= ref ? i <= ref : i >= ref; 0 <= ref ? i++ : i--){ results1.push(i); }
      return results1;
    }).apply(this), (function(_this) {
      return function(num, cb) {
        var worker;
        worker = _this.sub(_this.name + "#" + num, _this.schema.and[num]);
        return worker.describe(function(err, subtext) {
          if (err) {
            return cb(err);
          }
          return cb(null, "\n- " + (subtext.replace(/\n/g, '\n  ')));
        });
      };
    })(this), function(err, results) {
      if (err) {
        return cb(err);
      }
      text += results.join('') + '\n';
      return cb(null, text);
    });
  };

  exports.check = function(cb) {
    var i, ref, results1, skip;
    skip = rules.optional.check.call(this);
    if (skip instanceof Error) {
      return cb(skip);
    }
    if (skip) {
      return cb();
    }
    return async.eachSeries((function() {
      results1 = [];
      for (var i = 0, ref = this.schema.and.length - 1; 0 <= ref ? i <= ref : i >= ref; 0 <= ref ? i++ : i--){ results1.push(i); }
      return results1;
    }).apply(this), (function(_this) {
      return function(num, cb) {
        var worker;
        worker = _this.sub(_this.name + "#" + num, _this.schema.and[num], _this.value);
        return worker.check(function(err) {
          if (err) {
            return cb(err);
          }
          _this.value = worker.value;
          return cb();
        });
      };
    })(this), (function(_this) {
      return function(err) {
        if (err) {
          return cb(err);
        }
        return _this.sendSuccess(cb);
      };
    })(this));
  };

  exports.selfcheck = {
    title: "And",
    description: "the logic for multiple, serial schema definitions",
    type: 'object',
    allowedKeys: true,
    keys: util.extend({
      and: {
        title: "Conditions",
        description: "the list of all serial checks which have to succeed",
        type: 'array',
        entries: {
          title: "Condition",
          description: "one of the checks which have to succeed",
          type: 'object',
          mandatoryKeys: ['type']
        }
      }
    }, rules.baseSchema, {
      "default": {
        title: "Default Value",
        description: "the default value to use if nothing given",
        type: 'any',
        optional: true
      }
    })
  };

}).call(this);

//# sourceMappingURL=and.map