
/*
Boolean
=================================================
The value has to be a boolean. The value will be true for 1, 'true', 'on',
'yes', '+' and it will be considered as false for 0, 'false', 'off', 'no',
'-', null and undefined.
Other values are not allowed.

__Format options:__

- `format` - (list) with the values for false and true

__Example:__

``` coffee
validator.check
  name: 'test'        # name to be displayed in errors (optional)
  value: input        # value to check
  schema:             # definition of checks
    type: 'boolean'
, (err, result) ->
   * do something
```


Schema Specification
---------------------------------------------------
{@schema #selfcheck}
 */

(function() {
  var rules, util, valuesFalse, valuesTrue,
    indexOf = [].indexOf || function(item) { for (var i = 0, l = this.length; i < l; i++) { if (i in this && this[i] === item) return i; } return -1; };

  util = require('alinex-util');

  rules = require('../helper/rules');

  valuesTrue = ['true', '1', 'on', 'yes', '+', 1, true];

  valuesFalse = ['false', '0', 'off', 'no', '-', 0, false];

  exports.describe = function(cb) {
    var text, vFalse, vTrue;
    vTrue = valuesTrue.map(util.inspect).join(', ');
    vFalse = valuesFalse.map(util.inspect).join(', ');
    text = "A boolean value, which will be true for " + vTrue + " and will be considered as false for " + vFalse + ". ";
    text += rules.optional.describe.call(this);
    if (this.schema.format) {
      text += "The values " + (this.schema.format.join(', ')) + " will be used for output. ";
    }
    return cb(null, text);
  };

  exports.check = function(cb) {
    var ref, ref1, ref2, ref3, ref4, ref5, skip;
    skip = rules.optional.check.call(this);
    if (skip instanceof Error) {
      return cb(skip);
    }
    if (skip) {
      return cb();
    }
    if (typeof this.value === 'string') {
      this.value = this.value.trim().toLowerCase();
    }
    if (ref = this.value, indexOf.call(valuesTrue, ref) >= 0) {
      this.value = (ref1 = (ref2 = this.schema.format) != null ? ref2[1] : void 0) != null ? ref1 : true;
      return this.sendSuccess(cb);
    }
    if (ref3 = this.value, indexOf.call(valuesFalse, ref3) >= 0) {
      this.value = (ref4 = (ref5 = this.schema.format) != null ? ref5[0] : void 0) != null ? ref4 : false;
      return this.sendSuccess(cb);
    }
    return this.sendError("No boolean value given", cb);
  };

  exports.selfcheck = {
    title: "Boolean",
    description: "a boolean schema definition",
    type: 'object',
    allowedKeys: true,
    keys: util.extend({
      format: {
        title: "Format",
        description: "the display values for `false` and `true`",
        type: 'array',
        minLength: 2,
        maxLength: 2,
        optional: true
      }
    }, rules.baseSchema, {
      "default": {
        title: "Default Value",
        description: "the default value to use if nothing given",
        type: 'boolean',
        optional: true
      }
    })
  };

}).call(this);

//# sourceMappingURL=boolean.map