
/*
Function
=================================================
The value has to be a function.
Other values are not allowed.

__Example:__

``` coffee
validator.check
  name: 'test'        # name to be displayed in errors (optional)
  value: input        # value to check
  schema:             # definition of checks
    type: 'function'
, (err, result) ->
   * do something
```


Schema Specification
---------------------------------------------------
{@schema #selfcheck}
 */

(function() {
  var rules, util;

  util = require('alinex-util');

  rules = require('../helper/rules');

  exports.describe = function(cb) {
    var text;
    text = "The value has to be a function/class. ";
    text += rules.optional.describe.call(this);
    text = text.replace(/\. It's/, ' which is');
    return cb(null, text);
  };

  exports.check = function(cb) {
    var skip;
    skip = rules.optional.check.call(this);
    if (skip instanceof Error) {
      return cb(skip);
    }
    if (skip) {
      return cb();
    }
    if (!(this.value instanceof Function)) {
      return this.sendError("No function given as value", cb);
    }
    return this.sendSuccess(cb);
  };

  exports.selfcheck = {
    title: "Function",
    description: "a function schema definition",
    type: 'object',
    allowedKeys: true,
    keys: util.extend({}, rules.baseSchema, {
      "default": {
        title: "Default Value",
        description: "the default value to use if nothing given",
        type: 'function',
        optional: true
      }
    })
  };

}).call(this);

//# sourceMappingURL=function.map