
/*
Hostname
=================================================
The value has to be a valid hostname definition.


Schema Specification
---------------------------------------------------
{@schema #selfcheck}
 */

(function() {
  var rules, util;

  util = require('alinex-util');

  rules = require('../helper/rules');

  exports.describe = function(cb) {
    var text;
    text = 'A valid hostname. ';
    text += rules.optional.describe.call(this);
    text = text.replace(/\. It's/, ' which is');
    text += "This has to be a valid name according to [RFC 1123](http://tools.ietf.org/html/rfc1123)";
    return cb(null, text);
  };

  exports.check = function(cb) {
    var skip, worker;
    skip = rules.optional.check.call(this);
    if (skip instanceof Error) {
      return cb(skip);
    }
    if (skip) {
      return cb();
    }
    worker = this.sub(this.name + "#", {
      type: 'string',
      lowerCase: true,
      maxLength: 255,
      match: /^(([a-zA-Z0-9]|[a-zA-Z0-9][a-zA-Z0-9\-]{0,61}[a-zA-Z0-9])\.)*([a-zA-Z0-9]|[a-zA-Z0-9][a-zA-Z0-9\-]{0,61}[a-zA-Z0-9])$/
    }, this.value);
    return worker.check((function(_this) {
      return function(err) {
        if (err) {
          return cb(err);
        }
        _this.value = worker.value;
        return _this.sendSuccess(cb);
      };
    })(this));
  };

  exports.selfcheck = {
    title: "Hostname",
    description: "a hostname schema definition",
    type: 'object',
    allowedKeys: true,
    keys: util.extend({}, rules.baseSchema, {
      "default": {
        title: "Default Value",
        description: "the default value to use if nothing given",
        type: 'hostname',
        optional: true
      }
    })
  };

}).call(this);

//# sourceMappingURL=hostname.map