
/*
RegExp
=================================================
Check that the given value is a regular expression. If a text is given it will be
compiled into an regular expression.

Check options:
- `optional` - `Boolean` the value must not be present (will return null)


Schema Specification
---------------------------------------------------
{@schema #selfcheck}
 */

(function() {
  var rules, subcheck, util;

  util = require('alinex-util');

  rules = require('../helper/rules');

  subcheck = {
    type: 'or',
    or: [
      {
        type: 'object',
        instanceOf: RegExp
      }, {
        type: 'string',
        match: /^\/.*?\/[gim]*$/
      }
    ]
  };

  exports.describe = function(cb) {
    var text, worker;
    text = 'A valid regular expression. ';
    text += rules.optional.describe.call(this);
    text = text.replace(/\. It's/, ' which is');
    worker = this.sub(this.name + "#", subcheck, this.value);
    return worker.describe(function(err, subtext) {
      if (err) {
        return cb(err);
      }
      return cb(null, text + subtext);
    });
  };

  exports.check = function(cb) {
    var skip, worker;
    skip = rules.optional.check.call(this);
    if (skip instanceof Error) {
      return cb(skip);
    }
    if (skip) {
      return cb();
    }
    worker = this.sub(this.name + "#", subcheck, this.value);
    return worker.check((function(_this) {
      return function(err) {
        var error, parts;
        if (err) {
          return cb(err);
        }
        if (_this.value instanceof RegExp) {
          return _this.sendSuccess(cb);
        }
        parts = _this.value.match(/^\/(.*?)\/([gim]*)$/);
        try {
          _this.value = new RegExp(parts[1], parts[2]);
        } catch (error1) {
          error = error1;
          return _this.sendError(error.message, cb);
        }
        return _this.sendSuccess(cb);
      };
    })(this));
  };

  exports.selfcheck = {
    title: "RegExp",
    description: "a regexp schema definition",
    type: 'object',
    allowedKeys: true,
    keys: util.extend({}, rules.baseSchema, {
      "default": {
        title: "Default Value",
        description: "the default value to use if nothing given",
        type: 'regexp',
        optional: true
      }
    })
  };

}).call(this);

//# sourceMappingURL=regexp.map